===============
ant_connect_py
===============


    ant_connect_py Python package V2 is here! 


ant_connect_py V2 is a ground-up rewrite that offers some breaking changes compared to the previous version. 
The new version is designed to be more flexible, more efficient, and especially more user-friendly. 
The new version is also designed to be more modular, allowing users to easily extend the functionality of the package.


Note
====

If you are using ant_connect V1 (versions 2023.15.1 and lower) you might want to check the documentation for more details.
ant_connect_py V2 also ships with the latest version of ant_connect V1 built in so that you can incrementally upgrade your code base and projects.

Import as follows:
`from ant_connect import v1 as ant_connect_v1`
